@@ -1,4 +1,5 @@
 """Define package errors."""
+from typing import Dict, Type
 
 
 class AirVisualError(Exception):
@@ -32,7 +33,7 @@ class NoStationError(AirVisualError):
 
 
 class NotFoundError(AirVisualError):
-    """Define an error for when a city cannot be found."""
+    """Define an error for when a location (city or node) cannot be found."""
 
     pass
 
@@ -49,20 +50,22 @@ class UnauthorizedError(AirVisualError):
     pass
 
 
-ERROR_CODES = {
-    'api_key_expired': KeyExpiredError,
-    'call_limit_reached': LimitReachedError,
-    'city_not_found': NotFoundError,
-    'incorrect_api_key': InvalidKeyError,
-    'no_nearest_station': NoStationError,
-    'permission_denied': UnauthorizedError,
+ERROR_CODES: Dict[str, Type[AirVisualError]] = {
+    "api_key_expired": KeyExpiredError,
+    "call_limit_reached": LimitReachedError,
+    "city_not_found": NotFoundError,
+    "incorrect_api_key": InvalidKeyError,
+    "no_nearest_station": NoStationError,
+    "node not found": NotFoundError,
+    "permission_denied": UnauthorizedError,
 }
 
 
 def raise_error(error_type: str) -> None:
     """Raise the appropriate error based on error message."""
+    error: Type[AirVisualError]
     try:
-        [error] = [v for k, v in ERROR_CODES.items() if k in error_type]
-    except ValueError:
+        error = next((v for k, v in ERROR_CODES.items() if k in error_type))
+    except StopIteration:
         error = AirVisualError
     raise error(error_type)
